pub enum RemovalReason {
Expired,
Replaced,
RoomLeft,
}Available on crate feature
unstable-msc4354 only.Expand description
Why a sticky event disappeared from the map of a room.
Variants
Expired
The event stopped being sticky.
Replaced
A newer event with the same key and an empty content (a removal, in MSC4354 terms) replaced it.
RoomLeft
We left the room.