pub struct StickyEvent {
pub key: StickyKey,
pub event_id: OwnedEventId,
pub kind: TimelineEventKind,
pub expires_at: MilliSecondsSinceUnixEpoch,
}Available on crate feature
unstable-msc4354 only.Expand description
A sticky event that is currently live in the map of a room.
Fields
key: StickyKeyThe key of the event in the map.
event_id: OwnedEventIdThe event ID.
kind: TimelineEventKindThe event, decrypted if it was encrypted, along with its encryption info.
expires_at: MilliSecondsSinceUnixEpochWhen the event stops being sticky.
Implementations
Sourceimpl StickyEvent
impl StickyEvent
Sourcepub fn raw(&self) -> &Raw<AnySyncTimelineEvent>
pub fn raw(&self) -> &Raw<AnySyncTimelineEvent>
The event, decrypted if it was encrypted.
Sourcepub fn encryption_info(&self) -> Option<&Arc<EncryptionInfo>>
pub fn encryption_info(&self) -> Option<&Arc<EncryptionInfo>>
The encryption info of the event, if it was encrypted.