pub struct StickyEvents { /* private fields */ }Available on crate feature
unstable-msc4354 only.Expand description
The sticky events of a room.
This is a cheap-to-clone handle over the map of a room, which every clone
(and every clone of the Room it belongs to) shares.
Implementations
Sourceimpl StickyEvents
impl StickyEvents
Sourcepub fn live(&self) -> Vec<StickyEvent>
pub fn live(&self) -> Vec<StickyEvent>
The sticky events that are currently live, in no particular order.