pub struct StickyKey {
pub sender: OwnedUserId,
pub event_type: TimelineEventType,
pub sticky_key: String,
}Available on crate feature
unstable-msc4354 only.Expand description
The key of a sticky event in the map of a room.
MSC4354 keys the map by (room_id, sender, type, content.sticky_key); the
room is implied by the map this key belongs to.
Fields
sender: OwnedUserIdThe sender of the event.
event_type: TimelineEventTypeThe type of the event, e.g. m.rtc.member.
sticky_key: StringThe content.sticky_key of the event.